==> cdktf-provider-google-2.0.22-sources.jar: com/hashicorp/cdktf/providers/google/StorageTransferJobTransferSpecTransferOptions.java <==
package com.hashicorp.cdktf.providers.google;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.67.0 (build 2c027f5)", date = "2022-09-12T00:46:06.685Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.google.$Module.class, fqn = "@cdktf/provider-google.StorageTransferJobTransferSpecTransferOptions")
@software.amazon.jsii.Jsii.Proxy(StorageTransferJobTransferSpecTransferOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface StorageTransferJobTransferSpecTransferOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * Whether objects should be deleted from the source after they are transferred to the sink.
     * <p>
     * Note that this option and delete_objects_unique_in_sink are mutually exclusive.
     * <p>
     * Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/storage_transfer_job#delete_objects_from_source_after_transfer StorageTransferJob#delete_objects_from_source_after_transfer}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getDeleteObjectsFromSourceAfterTransfer() {
        return null;
    }

    /**
     * Whether objects that exist only in the sink should be deleted.
     * <p>
     * Note that this option and delete_objects_from_source_after_transfer are mutually exclusive.
     * <p>
     * Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/storage_transfer_job#delete_objects_unique_in_sink StorageTransferJob#delete_objects_unique_in_sink}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getDeleteObjectsUniqueInSink() {
        return null;
    }

    /**
     * Whether overwriting objects that already exist in the sink is allowed.
     * <p>
     * Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/storage_transfer_job#overwrite_objects_already_existing_in_sink StorageTransferJob#overwrite_objects_already_existing_in_sink}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getOverwriteObjectsAlreadyExistingInSink() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link StorageTransferJobTransferSpecTransferOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link StorageTransferJobTransferSpecTransferOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<StorageTransferJobTransferSpecTransferOptions> {
        java.lang.Object deleteObjectsFromSourceAfterTransfer;
        java.lang.Object deleteObjectsUniqueInSink;
        java.lang.Object overwriteObjectsAlreadyExistingInSink;

        /**
         * Sets the value of {@link StorageTransferJobTransferSpecTransferOptions#getDeleteObjectsFromSourceAfterTransfer}
         * @param deleteObjectsFromSourceAfterTransfer Whether objects should be deleted from the source after they are transferred to the sink.
         *                                             Note that this option and delete_objects_unique_in_sink are mutually exclusive.
         *                                             <p>
         *                                             Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/storage_transfer_job#delete_objects_from_source_after_transfer StorageTransferJob#delete_objects_from_source_after_transfer}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder deleteObjectsFromSourceAfterTransfer(java.lang.Boolean deleteObjectsFromSourceAfterTransfer) {
            this.deleteObjectsFromSourceAfterTransfer = deleteObjectsFromSourceAfterTransfer;
            return this;
        }

        /**
         * Sets the value of {@link StorageTransferJobTransferSpecTransferOptions#getDeleteObjectsFromSourceAfterTransfer}
         * @param deleteObjectsFromSourceAfterTransfer Whether objects should be deleted from the source after they are transferred to the sink.
         *                                             Note that this option and delete_objects_unique_in_sink are mutually exclusive.
         *                                             <p>
         *                                             Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/storage_transfer_job#delete_objects_from_source_after_transfer StorageTransferJob#delete_objects_from_source_after_transfer}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder deleteObjectsFromSourceAfterTransfer(com.hashicorp.cdktf.IResolvable deleteObjectsFromSourceAfterTransfer) {
            this.deleteObjectsFromSourceAfterTransfer = deleteObjectsFromSourceAfterTransfer;
            return this;
        }

        /**
         * Sets the value of {@link StorageTransferJobTransferSpecTransferOptions#getDeleteObjectsUniqueInSink}
         * @param deleteObjectsUniqueInSink Whether objects that exist only in the sink should be deleted.
         *                                  Note that this option and delete_objects_from_source_after_transfer are mutually exclusive.
         *                                  <p>
         *                                  Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/storage_transfer_job#delete_objects_unique_in_sink StorageTransferJob#delete_objects_unique_in_sink}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder deleteObjectsUniqueInSink(java.lang.Boolean deleteObjectsUniqueInSink) {
            this.deleteObjectsUniqueInSink = deleteObjectsUniqueInSink;
            return this;
        }

        /**
         * Sets the value of {@link StorageTransferJobTransferSpecTransferOptions#getDeleteObjectsUniqueInSink}
         * @param deleteObjectsUniqueInSink Whether objects that exist only in the sink should be deleted.
         *                                  Note that this option and delete_objects_from_source_after_transfer are mutually exclusive.
         *                                  <p>
         *                                  Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/storage_transfer_job#delete_objects_unique_in_sink StorageTransferJob#delete_objects_unique_in_sink}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder deleteObjectsUniqueInSink(com.hashicorp.cdktf.IResolvable deleteObjectsUniqueInSink) {
            this.deleteObjectsUniqueInSink = deleteObjectsUniqueInSink;
            return this;
        }

        /**
         * Sets the value of {@link StorageTransferJobTransferSpecTransferOptions#getOverwriteObjectsAlreadyExistingInSink}
         * @param overwriteObjectsAlreadyExistingInSink Whether overwriting objects that already exist in the sink is allowed.
         *                                              Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/storage_transfer_job#overwrite_objects_already_existing_in_sink StorageTransferJob#overwrite_objects_already_existing_in_sink}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder overwriteObjectsAlreadyExistingInSink(java.lang.Boolean overwriteObjectsAlreadyExistingInSink) {
            this.overwriteObjectsAlreadyExistingInSink = overwriteObjectsAlreadyExistingInSink;
            return this;
        }

        /**
         * Sets the value of {@link StorageTransferJobTransferSpecTransferOptions#getOverwriteObjectsAlreadyExistingInSink}
         * @param overwriteObjectsAlreadyExistingInSink Whether overwriting objects that already exist in the sink is allowed.
         *                                              Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/storage_transfer_job#overwrite_objects_already_existing_in_sink StorageTransferJob#overwrite_objects_already_existing_in_sink}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder overwriteObjectsAlreadyExistingInSink(com.hashicorp.cdktf.IResolvable overwriteObjectsAlreadyExistingInSink) {
            this.overwriteObjectsAlreadyExistingInSink = overwriteObjectsAlreadyExistingInSink;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link StorageTransferJobTransferSpecTransferOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public StorageTransferJobTransferSpecTransferOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link StorageTransferJobTransferSpecTransferOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements StorageTransferJobTransferSpecTransferOptions {
        private final java.lang.Object deleteObjectsFromSourceAfterTransfer;
        private final java.lang.Object deleteObjectsUniqueInSink;
        private final java.lang.Object overwriteObjectsAlreadyExistingInSink;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.deleteObjectsFromSourceAfterTransfer = software.amazon.jsii.Kernel.get(this, "deleteObjectsFromSourceAfterTransfer", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
            this.deleteObjectsUniqueInSink = software.amazon.jsii.Kernel.get(this, "deleteObjectsUniqueInSink", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
            this.overwriteObjectsAlreadyExistingInSink = software.amazon.jsii.Kernel.get(this, "overwriteObjectsAlreadyExistingInSink", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.deleteObjectsFromSourceAfterTransfer = builder.deleteObjectsFromSourceAfterTransfer;
            this.deleteObjectsUniqueInSink = builder.deleteObjectsUniqueInSink;
            this.overwriteObjectsAlreadyExistingInSink = builder.overwriteObjectsAlreadyExistingInSink;
        }

        @Override
        public final java.lang.Object getDeleteObjectsFromSourceAfterTransfer() {
            return this.deleteObjectsFromSourceAfterTransfer;
        }

        @Override
        public final java.lang.Object getDeleteObjectsUniqueInSink() {
            return this.deleteObjectsUniqueInSink;
        }

        @Override
        public final java.lang.Object getOverwriteObjectsAlreadyExistingInSink() {
            return this.overwriteObjectsAlreadyExistingInSink;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getDeleteObjectsFromSourceAfterTransfer() != null) {
                data.set("deleteObjectsFromSourceAfterTransfer", om.valueToTree(this.getDeleteObjectsFromSourceAfterTransfer()));
            }
            if (this.getDeleteObjectsUniqueInSink() != null) {
                data.set("deleteObjectsUniqueInSink", om.valueToTree(this.getDeleteObjectsUniqueInSink()));
            }
            if (this.getOverwriteObjectsAlreadyExistingInSink() != null) {
                data.set("overwriteObjectsAlreadyExistingInSink", om.valueToTree(this.getOverwriteObjectsAlreadyExistingInSink()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-google.StorageTransferJobTransferSpecTransferOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            StorageTransferJobTransferSpecTransferOptions.Jsii$Proxy that = (StorageTransferJobTransferSpecTransferOptions.Jsii$Proxy) o;

            if (this.deleteObjectsFromSourceAfterTransfer != null ? !this.deleteObjectsFromSourceAfterTransfer.equals(that.deleteObjectsFromSourceAfterTransfer) : that.deleteObjectsFromSourceAfterTransfer != null) return false;
            if (this.deleteObjectsUniqueInSink != null ? !this.deleteObjectsUniqueInSink.equals(that.deleteObjectsUniqueInSink) : that.deleteObjectsUniqueInSink != null) return false;
            return this.overwriteObjectsAlreadyExistingInSink != null ? this.overwriteObjectsAlreadyExistingInSink.equals(that.overwriteObjectsAlreadyExistingInSink) : that.overwriteObjectsAlreadyExistingInSink == null;
        }

        @Override
        public final int hashCode() {
            int result = this.deleteObjectsFromSourceAfterTransfer != null ? this.deleteObjectsFromSourceAfterTransfer.hashCode() : 0;
            result = 31 * result + (this.deleteObjectsUniqueInSink != null ? this.deleteObjectsUniqueInSink.hashCode() : 0);
            result = 31 * result + (this.overwriteObjectsAlreadyExistingInSink != null ? this.overwriteObjectsAlreadyExistingInSink.hashCode() : 0);
            return result;
        }
    }
}

==> cdktf-provider-google-2.0.46-sources.jar: com/hashicorp/cdktf/providers/google/StorageTransferJobTransferSpecTransferOptions.java <==
package com.hashicorp.cdktf.providers.google;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.69.0 (build f656c31)", date = "2022-10-03T00:49:23.497Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.google.$Module.class, fqn = "@cdktf/provider-google.StorageTransferJobTransferSpecTransferOptions")
@software.amazon.jsii.Jsii.Proxy(StorageTransferJobTransferSpecTransferOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface StorageTransferJobTransferSpecTransferOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * Whether objects should be deleted from the source after they are transferred to the sink.
     * <p>
     * Note that this option and delete_objects_unique_in_sink are mutually exclusive.
     * <p>
     * Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/storage_transfer_job#delete_objects_from_source_after_transfer StorageTransferJob#delete_objects_from_source_after_transfer}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getDeleteObjectsFromSourceAfterTransfer() {
        return null;
    }

    /**
     * Whether objects that exist only in the sink should be deleted.
     * <p>
     * Note that this option and delete_objects_from_source_after_transfer are mutually exclusive.
     * <p>
     * Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/storage_transfer_job#delete_objects_unique_in_sink StorageTransferJob#delete_objects_unique_in_sink}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getDeleteObjectsUniqueInSink() {
        return null;
    }

    /**
     * Whether overwriting objects that already exist in the sink is allowed.
     * <p>
     * Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/storage_transfer_job#overwrite_objects_already_existing_in_sink StorageTransferJob#overwrite_objects_already_existing_in_sink}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getOverwriteObjectsAlreadyExistingInSink() {
        return null;
    }

    /**
     * When to overwrite objects that already exist in the sink. If not set, overwrite behavior is determined by overwriteObjectsAlreadyExistingInSink.
     * <p>
     * Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/storage_transfer_job#overwrite_when StorageTransferJob#overwrite_when}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getOverwriteWhen() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link StorageTransferJobTransferSpecTransferOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link StorageTransferJobTransferSpecTransferOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<StorageTransferJobTransferSpecTransferOptions> {
        java.lang.Object deleteObjectsFromSourceAfterTransfer;
        java.lang.Object deleteObjectsUniqueInSink;
        java.lang.Object overwriteObjectsAlreadyExistingInSink;
        java.lang.String overwriteWhen;

        /**
         * Sets the value of {@link StorageTransferJobTransferSpecTransferOptions#getDeleteObjectsFromSourceAfterTransfer}
         * @param deleteObjectsFromSourceAfterTransfer Whether objects should be deleted from the source after they are transferred to the sink.
         *                                             Note that this option and delete_objects_unique_in_sink are mutually exclusive.
         *                                             <p>
         *                                             Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/storage_transfer_job#delete_objects_from_source_after_transfer StorageTransferJob#delete_objects_from_source_after_transfer}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder deleteObjectsFromSourceAfterTransfer(java.lang.Boolean deleteObjectsFromSourceAfterTransfer) {
            this.deleteObjectsFromSourceAfterTransfer = deleteObjectsFromSourceAfterTransfer;
            return this;
        }

        /**
         * Sets the value of {@link StorageTransferJobTransferSpecTransferOptions#getDeleteObjectsFromSourceAfterTransfer}
         * @param deleteObjectsFromSourceAfterTransfer Whether objects should be deleted from the source after they are transferred to the sink.
         *                                             Note that this option and delete_objects_unique_in_sink are mutually exclusive.
         *                                             <p>
         *                                             Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/storage_transfer_job#delete_objects_from_source_after_transfer StorageTransferJob#delete_objects_from_source_after_transfer}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder deleteObjectsFromSourceAfterTransfer(com.hashicorp.cdktf.IResolvable deleteObjectsFromSourceAfterTransfer) {
            this.deleteObjectsFromSourceAfterTransfer = deleteObjectsFromSourceAfterTransfer;
            return this;
        }

        /**
         * Sets the value of {@link StorageTransferJobTransferSpecTransferOptions#getDeleteObjectsUniqueInSink}
         * @param deleteObjectsUniqueInSink Whether objects that exist only in the sink should be deleted.
         *                                  Note that this option and delete_objects_from_source_after_transfer are mutually exclusive.
         *                                  <p>
         *                                  Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/storage_transfer_job#delete_objects_unique_in_sink StorageTransferJob#delete_objects_unique_in_sink}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder deleteObjectsUniqueInSink(java.lang.Boolean deleteObjectsUniqueInSink) {
            this.deleteObjectsUniqueInSink = deleteObjectsUniqueInSink;
            return this;
        }

        /**
         * Sets the value of {@link StorageTransferJobTransferSpecTransferOptions#getDeleteObjectsUniqueInSink}
         * @param deleteObjectsUniqueInSink Whether objects that exist only in the sink should be deleted.
         *                                  Note that this option and delete_objects_from_source_after_transfer are mutually exclusive.
         *                                  <p>
         *                                  Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/storage_transfer_job#delete_objects_unique_in_sink StorageTransferJob#delete_objects_unique_in_sink}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder deleteObjectsUniqueInSink(com.hashicorp.cdktf.IResolvable deleteObjectsUniqueInSink) {
            this.deleteObjectsUniqueInSink = deleteObjectsUniqueInSink;
            return this;
        }

        /**
         * Sets the value of {@link StorageTransferJobTransferSpecTransferOptions#getOverwriteObjectsAlreadyExistingInSink}
         * @param overwriteObjectsAlreadyExistingInSink Whether overwriting objects that already exist in the sink is allowed.
         *                                              Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/storage_transfer_job#overwrite_objects_already_existing_in_sink StorageTransferJob#overwrite_objects_already_existing_in_sink}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder overwriteObjectsAlreadyExistingInSink(java.lang.Boolean overwriteObjectsAlreadyExistingInSink) {
            this.overwriteObjectsAlreadyExistingInSink = overwriteObjectsAlreadyExistingInSink;
            return this;
        }

        /**
         * Sets the value of {@link StorageTransferJobTransferSpecTransferOptions#getOverwriteObjectsAlreadyExistingInSink}
         * @param overwriteObjectsAlreadyExistingInSink Whether overwriting objects that already exist in the sink is allowed.
         *                                              Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/storage_transfer_job#overwrite_objects_already_existing_in_sink StorageTransferJob#overwrite_objects_already_existing_in_sink}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder overwriteObjectsAlreadyExistingInSink(com.hashicorp.cdktf.IResolvable overwriteObjectsAlreadyExistingInSink) {
            this.overwriteObjectsAlreadyExistingInSink = overwriteObjectsAlreadyExistingInSink;
            return this;
        }

        /**
         * Sets the value of {@link StorageTransferJobTransferSpecTransferOptions#getOverwriteWhen}
         * @param overwriteWhen When to overwrite objects that already exist in the sink. If not set, overwrite behavior is determined by overwriteObjectsAlreadyExistingInSink.
         *                      Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/storage_transfer_job#overwrite_when StorageTransferJob#overwrite_when}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder overwriteWhen(java.lang.String overwriteWhen) {
            this.overwriteWhen = overwriteWhen;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link StorageTransferJobTransferSpecTransferOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public StorageTransferJobTransferSpecTransferOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link StorageTransferJobTransferSpecTransferOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements StorageTransferJobTransferSpecTransferOptions {
        private final java.lang.Object deleteObjectsFromSourceAfterTransfer;
        private final java.lang.Object deleteObjectsUniqueInSink;
        private final java.lang.Object overwriteObjectsAlreadyExistingInSink;
        private final java.lang.String overwriteWhen;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.deleteObjectsFromSourceAfterTransfer = software.amazon.jsii.Kernel.get(this, "deleteObjectsFromSourceAfterTransfer", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
            this.deleteObjectsUniqueInSink = software.amazon.jsii.Kernel.get(this, "deleteObjectsUniqueInSink", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
            this.overwriteObjectsAlreadyExistingInSink = software.amazon.jsii.Kernel.get(this, "overwriteObjectsAlreadyExistingInSink", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
            this.overwriteWhen = software.amazon.jsii.Kernel.get(this, "overwriteWhen", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.deleteObjectsFromSourceAfterTransfer = builder.deleteObjectsFromSourceAfterTransfer;
            this.deleteObjectsUniqueInSink = builder.deleteObjectsUniqueInSink;
            this.overwriteObjectsAlreadyExistingInSink = builder.overwriteObjectsAlreadyExistingInSink;
            this.overwriteWhen = builder.overwriteWhen;
        }

        @Override
        public final java.lang.Object getDeleteObjectsFromSourceAfterTransfer() {
            return this.deleteObjectsFromSourceAfterTransfer;
        }

        @Override
        public final java.lang.Object getDeleteObjectsUniqueInSink() {
            return this.deleteObjectsUniqueInSink;
        }

        @Override
        public final java.lang.Object getOverwriteObjectsAlreadyExistingInSink() {
            return this.overwriteObjectsAlreadyExistingInSink;
        }

        @Override
        public final java.lang.String getOverwriteWhen() {
            return this.overwriteWhen;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getDeleteObjectsFromSourceAfterTransfer() != null) {
                data.set("deleteObjectsFromSourceAfterTransfer", om.valueToTree(this.getDeleteObjectsFromSourceAfterTransfer()));
            }
            if (this.getDeleteObjectsUniqueInSink() != null) {
                data.set("deleteObjectsUniqueInSink", om.valueToTree(this.getDeleteObjectsUniqueInSink()));
            }
            if (this.getOverwriteObjectsAlreadyExistingInSink() != null) {
                data.set("overwriteObjectsAlreadyExistingInSink", om.valueToTree(this.getOverwriteObjectsAlreadyExistingInSink()));
            }
            if (this.getOverwriteWhen() != null) {
                data.set("overwriteWhen", om.valueToTree(this.getOverwriteWhen()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-google.StorageTransferJobTransferSpecTransferOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            StorageTransferJobTransferSpecTransferOptions.Jsii$Proxy that = (StorageTransferJobTransferSpecTransferOptions.Jsii$Proxy) o;

            if (this.deleteObjectsFromSourceAfterTransfer != null ? !this.deleteObjectsFromSourceAfterTransfer.equals(that.deleteObjectsFromSourceAfterTransfer) : that.deleteObjectsFromSourceAfterTransfer != null) return false;
            if (this.deleteObjectsUniqueInSink != null ? !this.deleteObjectsUniqueInSink.equals(that.deleteObjectsUniqueInSink) : that.deleteObjectsUniqueInSink != null) return false;
            if (this.overwriteObjectsAlreadyExistingInSink != null ? !this.overwriteObjectsAlreadyExistingInSink.equals(that.overwriteObjectsAlreadyExistingInSink) : that.overwriteObjectsAlreadyExistingInSink != null) return false;
            return this.overwriteWhen != null ? this.overwriteWhen.equals(that.overwriteWhen) : that.overwriteWhen == null;
        }

        @Override
        public final int hashCode() {
            int result = this.deleteObjectsFromSourceAfterTransfer != null ? this.deleteObjectsFromSourceAfterTransfer.hashCode() : 0;
            result = 31 * result + (this.deleteObjectsUniqueInSink != null ? this.deleteObjectsUniqueInSink.hashCode() : 0);
            result = 31 * result + (this.overwriteObjectsAlreadyExistingInSink != null ? this.overwriteObjectsAlreadyExistingInSink.hashCode() : 0);
            result = 31 * result + (this.overwriteWhen != null ? this.overwriteWhen.hashCode() : 0);
            return result;
        }
    }
}
